@@ -5,20 +5,6 @@ from .managers import BulkManager,chunks
 from .helper import fetch_celex_resource
 
 
-class WordManager(BulkManager):
-    tbl_name = 'celex_word'
-    cols = ['FreqDict_id','Label','Category_id','Frequency']
-
-
-class TranscriptionManager(BulkManager):
-    tbl_name = 'celex_transcription'
-    cols = ['Transcription','Word_id']
-
-class SpellingManager(BulkManager):
-    tbl_name = 'celex_spelling'
-    cols = ['Label','Word_id']
-
-
 
 #class SegmentType(models.Model):
 #    Label = models.CharField(max_length=10)
