@@ -1,4 +1,4 @@
-
+import os
 import re
 
 from celery import task,chord,group,chain
@@ -7,10 +7,12 @@ from celery.utils.log import get_task_logger
 
 from django.conf import settings
 
+from ngrams.utils import in_trigram_context_entropy
+
 from .models import *
 from .managers import BulkManager,chunks
 
-from .helper import fetch_media_resource
+from .helper import fetch_media_resource,get_phone_dist,is_neighbour
 
 logger = get_task_logger(__name__)
 
@@ -237,7 +239,7 @@ def loadTransWF(wfs):
 @task()
 def doStringSelect(form):
     qs = WordForm.objects.all()
-    qs = qs.filter(lemma__category__in = form['categories']).prefetch_related()
+    qs = qs.filter(lemma__category__in = form['categories']).select_related('lemma','lemma__category').prefetch_related('orthographies','transcriptions')
     if form['exclude_punctuation']:
         qs = qs.exclude(orthographies__spelling__contains="'")
         qs = qs.exclude(orthographies__spelling__contains=".")
@@ -246,43 +248,59 @@ def doStringSelect(form):
     if form['exclude_titlecase']:
         qs = qs.exclude(orthographies__spelling__regex="^[A-Z]")
     qs = qs.filter(transcriptions__cvskel = form['cvskel'])
-    with open(os.path.join(fetch_media_resource("Results"),"Celex","ConCon.txt"),'w') as f:
-        f.write("\t".join(["orth_one","orth_two","trans_one",'trans_two',
-                            "cat_one","cat_two","freq_one","freq_two",
-                            "lemma_one","lemma_two",
-                            "lemma_freq_one","lemma_freq_two",
-                            "phon_distance","in_context_entropy",
-                            ]))
-        f.write("\n")
-        for i in range(len(qs)):
-            q = qs[i]
-            if len(q.transcriptions.all()) != 1:
+    qs = qs.filter(frequency__gt = 1.0)
+    comps = []
+    print len(qs)
+    for i in range(len(qs)):
+        q = qs[i]
+        if i % 500 == 0:
+            print i
+        if len(q.transcriptions.all()) != 1:
+            continue
+        for j in range(i+1,len(qs)):
+            s = qs[j]
+            if len(s.transcriptions.all()) != 1:
                 continue
-            t_one = str(q.transcriptions.all()[0]).encode('ascii')
-            o_one = [str(x) for x in q.orthographies.all()]
-            for j in range(i+1,len(qs)):
-                s = qs[j]
-                if len(s.transcriptions.all()) != 1:
-                    continue
-                t_two = str(s.transcriptions.all()[0]).encode('ascii')
-                o_two = [str(x) for x in s.orthographies.all()]
-                phon_dist = get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two))
-                #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
-                #    if t_one != t_two:
-                #        continue
-                #    phon_dist = "homophone"
-                #else:
-                #    phon_dist = "neighbour"
-                in_context_entropy = in_trigram_context_entropy(o_one,o_two)
-                c_one = str(q.lemma.category.label).encode('ascii')
-                c_two = str(s.lemma.category.label).encode('ascii')
-                f_one = q.frequency
-                f_two = s.frequency
-                L_one = str(q.lemma.label).encode('ascii')
-                L_two = str(s.lemma.label).encode('ascii')
-                LFreq_one = q.lemma.frequency
-                LFreq_two = s.lemma.frequency
-                f.write('\t'.join([':'.join(o_one),':'.join(o_two),t_one,t_two,
-                                    c_one,c_two,f_one,f_two,L_one,L_two,
-                                    LFreq_one,LFreq_two,phon_dist,in_context_entropy]))
+            comps.append((q,s))
+    print(len(comps))
+    c2 = chord(group([analyze_block.s(x) for x in chunks(comps,1000)]))(combine_results.s())
+    c2.get()
+
+@task()
+def analyze_block(comp):
+    output = []
+    for c in comp:
+        q = c[0]
+        s = c[1]
+        t_one = str(q.transcriptions.all()[0]).encode('ascii')
+        o_one = [str(x) for x in q.orthographies.all()]
+        t_two = str(s.transcriptions.all()[0]).encode('ascii')
+        o_two = [str(x) for x in s.orthographies.all()]
+        phon_dist = str(get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two)))
+        #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
+        #    if t_one != t_two:
+        #        continue
+        #    phon_dist = "homophone"
+        #else:
+        #    phon_dist = "neighbour"
+        in_context_entropy = str(in_trigram_context_entropy(o_one,o_two))
+        c_one = str(q.lemma.category.label).encode('ascii')
+        c_two = str(s.lemma.category.label).encode('ascii')
+        f_one = str(q.frequency)
+        f_two = str(s.frequency)
+        L_one = str(q.lemma.label).encode('ascii')
+        L_two = str(s.lemma.label).encode('ascii')
+        LFreq_one = str(q.lemma.frequency)
+        LFreq_two = str(s.lemma.frequency)
+        output.append([':'.join(o_one),':'.join(o_two),t_one,t_two,
+                                c_one,c_two,f_one,f_two,L_one,L_two,
+                                LFreq_one,LFreq_two,phon_dist,in_context_entropy])
+    return output
+
+@task()
+def combine_results(allout):
+    with open(os.path.join(fetch_media_resource("Results"),"Celex","ConCon.txt"),'w') as f:
+        for l in allout:
+            for line in allout:
+                f.write("\t".join(line))
                 f.write("\n")
