@@ -15,7 +15,7 @@ from ngrams.utils import in_trigram_context_entropy
 from .models import *
 from .forms import *
 from .helper import fetch_celex_resource
-from .tasks import doReset
+from .tasks import doReset,doStringSelect
 
 #old
 #call_command('reset','stimuli', interactive=False,verbosity=0)
@@ -72,7 +72,7 @@ def string_selection(request):
     if request.method == 'POST':
         form = StringForm(request.POST)
         if form.is_valid():
-            doStringSelect.deleay(form.cleaned_data)
+            doStringSelect.delay(form.cleaned_data)
             return redirect(index)
     form = StringForm()
     return render(request,'celex/form.html',{'form':form})
